summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLin Jen-Shin <godfat@godfat.org>2018-04-13 18:04:19 +0800
committerLin Jen-Shin <godfat@godfat.org>2018-04-13 18:04:19 +0800
commit62f076c8ba25af6a3d6c5a779fbb80f1a2cace2d (patch)
tree96194769e443eea029130af6a20e513873c8758d
parentab98308db7d907e5fad53d2b1e3435960a1665cd (diff)
downloadgitlab-ce-use-the-ee-method-to-check-com.tar.gz
Use subdomain check from EE to check staginguse-the-ee-method-to-check-com
So this is more aligning with EE and it's more robust
-rw-r--r--lib/gitlab.rb15
1 files changed, 10 insertions, 5 deletions
diff --git a/lib/gitlab.rb b/lib/gitlab.rb
index 37ce01925bb..eaf6b208128 100644
--- a/lib/gitlab.rb
+++ b/lib/gitlab.rb
@@ -3,14 +3,19 @@ require_dependency 'gitlab/git'
module Gitlab
COM_URL = 'https://gitlab.com'.freeze
APP_DIRS_PATTERN = %r{^/?(app|config|ee|lib|spec|\(\w*\))}
+ SUBDOMAIN_REGEX = %r{\Ahttps://[a-z0-9]+\.gitlab\.com\z}
def self.com?
- # Check `staging?` as well to keep parity with gitlab.com
- Gitlab.config.gitlab.url == COM_URL || staging?
+ # Check `gl_subdomain?` as well to keep parity with gitlab.com
+ Gitlab.config.gitlab.url == COM_URL || gl_subdomain?
end
- def self.staging?
- Gitlab.config.gitlab.url == 'https://staging.gitlab.com'
+ def self.gl_subdomain?
+ SUBDOMAIN_REGEX === Gitlab.config.gitlab.url
+ end
+
+ def self.dev_env_or_com?
+ Rails.env.test? || Rails.env.development? || com?
end
def self.dev?
@@ -18,6 +23,6 @@ module Gitlab
end
def self.inc_controlled?
- dev? || staging? || com?
+ dev? || com?
end
end